@@ -58,8 +58,9 @@ def merge_iterators(iterators, key=None):
         - To different key getter, set key as a list:
           one key per iterator, in the same order.
     
+    >>> from pyf.dataflow.merging import merge_iterators
     >>> list(merge_iterators([xrange(4), xrange(1,5), [2,3]]))
-    ... [(0, None, None), (1, 1, None), (2, 2, 2), (3, 3, 3), (None, 4, None)]
+    [(0, None, None), (1, 1, None), (2, 2, 2), (3, 3, 3), (None, 4, None)]
     '''
     itlen = len(iterators)
 
